@@ -1,11 +1,11 @@
 import functools
 import operator
 import pickle
+import platform
 import sys
 from collections import OrderedDict
 from io import BytesIO
 
-import env
 import numpy as np
 import pytest
 from numpy.testing import assert_array_equal
@@ -589,6 +589,12 @@ def test_project():
     with pytest.raises(ValueError):
         h.project(2, 1)
 
+    with pytest.raises(ValueError):
+        h.project(9)
+
+    with pytest.raises(ValueError):
+        h.project(-1)
+
 
 def test_shrink_1d():
     h = bh.Histogram(bh.axis.Regular(20, 1, 5))
@@ -966,6 +972,9 @@ def test_fill_with_sequence_0():
         c[1, 2, 3]
 
 
+@pytest.mark.xfail(
+    platform.machine() == "ppc64le", reason="ppc64le bug (TBD)", strict=False
+)
 def test_fill_with_sequence_1():
     def fa(*args):
         return np.array(args, dtype=float)
@@ -1064,6 +1073,10 @@ def test_fill_with_sequence_3():
     assert_array_equal(h.view(True), [3, 1])
 
 
+@pytest.mark.skipif(
+    platform.machine() == "ppc64le" and sys.version_info < (3, 8),
+    reason="ppc64le segfault",
+)
 def test_fill_with_sequence_4():
     h = bh.Histogram(
         bh.axis.StrCategory([], growth=True), bh.axis.Integer(0, 0, growth=True)
@@ -1104,7 +1117,7 @@ def test_axes_lifetime():
 
     ax = h.axes[0]
 
-    if env.CPYTHON:
+    if platform.python_implementation == "CPython":
         # 2 is the minimum refcount, so the *python* object should be deleted
         # after the del; hopefully the C++ object lives through the axis instance.
         assert sys.getrefcount(h) == 2
