@@ -1,3 +1,5 @@
+import math
+
 import numpy as np
 import pytest
 from numpy.testing import assert_array_equal
@@ -258,3 +260,42 @@ def test_summing_weighted_mean_storage():
     assert s1.sum_of_weights == approx(s2.sum_of_weights)
     assert s1.sum_of_weights_squared == approx(s2.sum_of_weights_squared)
     assert s1.variance == approx(s2.variance)
+
+
+# Raised on Gitter
+def test_UHI_variance_counts():
+    h = bh.Histogram(
+        bh.axis.Regular(bins=1, start=0, stop=1), storage=bh.storage.WeightedMean()
+    )
+    h.fill(0.5, sample=[1], weight=[0.5])
+    h.fill(0.5, sample=[2], weight=[0.4])
+    assert not math.isnan(h.variances()[0])
+
+    h = bh.Histogram(
+        bh.axis.Regular(bins=1, start=0, stop=1), storage=bh.storage.WeightedMean()
+    )
+    h.fill(0.5, sample=[1], weight=[0.5])
+    h.fill(0.5, sample=[1], weight=[0.5])
+    assert not math.isnan(h.variances()[0])
+
+
+@pytest.mark.parametrize(
+    "storage",
+    [
+        bh.storage.Int64,
+        bh.storage.Double,
+        bh.storage.AtomicInt64,
+        bh.storage.Unlimited,
+        bh.storage.Weight,
+        bh.storage.Mean,
+        bh.storage.WeightedMean,
+    ],
+)
+def test_empty_axis_histogram(storage):
+    h2d = bh.Histogram(
+        bh.axis.Regular(10, 0, 10),
+        bh.axis.StrCategory([], growth=True),
+        storage=storage(),
+    )
+    assert h2d.sum() == h2d.storage_type.accumulator()
+    assert h2d.sum(flow=True) == h2d.storage_type.accumulator()
