@@ -1,5 +1,7 @@
+import numpy as np
 import pytest
 from numpy.testing import assert_allclose
+from pytest import approx
 
 import boost_histogram as bh
 
@@ -65,9 +67,14 @@ def test_view_add(v):
     assert_allclose(v2.value, [2, 5, 4, 3])
     assert_allclose(v2.variance, [4, 7, 6, 5])
 
-    v += 2
-    assert_allclose(v.value, [2, 5, 4, 3])
-    assert_allclose(v.variance, [4, 7, 6, 5])
+    v2 = v.copy()
+    v2 += 2
+    assert_allclose(v2.value, [2, 5, 4, 3])
+    assert_allclose(v2.variance, [4, 7, 6, 5])
+
+    v2 = v + v
+    assert_allclose(v2.value, v.value * 2)
+    assert_allclose(v2.variance, v.variance * 2)
 
 
 def test_view_sub(v):
@@ -83,9 +90,14 @@ def test_view_sub(v):
     assert_allclose(v2.value, [1, -2, -1, 0])
     assert_allclose(v2.variance, [1, 4, 3, 2])
 
-    v -= 2
-    assert_allclose(v.value, [-2, 1, 0, -1])
-    assert_allclose(v.variance, [4, 7, 6, 5])
+    v2 = v.copy()
+    v2 -= 2
+    assert_allclose(v2.value, [-2, 1, 0, -1])
+    assert_allclose(v2.variance, [4, 7, 6, 5])
+
+    v2 = v - v
+    assert_allclose(v2.value, [0, 0, 0, 0])
+    assert_allclose(v2.variance, v.variance * 2)
 
 
 def test_view_unary(v):
@@ -173,3 +185,17 @@ def test_view_assign_wmean():
     assert w[0].sum_of_weights_squared == 1
     assert w.value[0] == 2
     assert w[0].variance == 3
+
+
+# Issue #696
+def test_view_cumsum():
+    h = bh.Histogram(
+        bh.axis.Integer(1, 10, underflow=True, overflow=False),
+        storage=bh.storage.Weight(),
+    )
+    h.fill([2, 3], weight=[1.5, 2.5])
+
+    view = h.view()
+    c_view = np.cumsum(view)
+    assert c_view.value == approx(np.cumsum(view.value))
+    assert c_view.variance == approx(np.cumsum(view.variance))
